# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import account_pb2 as gateway_dot_account__pb2
from . import aws_iam_role_binding_pb2 as gateway_dot_aws__iam__role__binding__pb2
from . import batch_job_pb2 as gateway_dot_batch__job__pb2
from . import cluster_pb2 as gateway_dot_cluster__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import environment_pb2 as gateway_dot_environment__pb2
from . import model_pb2 as gateway_dot_model__pb2
from . import node_pool_pb2 as gateway_dot_node__pool__pb2
from . import sign_in_pb2 as gateway_dot_sign__in__pb2
from . import snapshot_pb2 as gateway_dot_snapshot__pb2
from . import user_pb2 as gateway_dot_user__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class GatewayStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SignIn = channel.unary_unary(
                '/gateway.Gateway/SignIn',
                request_serializer=gateway_dot_sign__in__pb2.SignInRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetOAuthArguments = channel.unary_unary(
                '/gateway.Gateway/GetOAuthArguments',
                request_serializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsRequest.SerializeToString,
                response_deserializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsResponse.FromString,
                )
        self.CreateAccount = channel.unary_unary(
                '/gateway.Gateway/CreateAccount',
                request_serializer=gateway_dot_account__pb2.CreateAccountRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.Account.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/gateway.Gateway/GetAccount',
                request_serializer=gateway_dot_account__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.Account.FromString,
                )
        self.ListAccounts = channel.unary_unary(
                '/gateway.Gateway/ListAccounts',
                request_serializer=gateway_dot_account__pb2.ListAccountsRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.ListAccountsResponse.FromString,
                )
        self.UpdateAccount = channel.unary_unary(
                '/gateway.Gateway/UpdateAccount',
                request_serializer=gateway_dot_account__pb2.UpdateAccountRequest.SerializeToString,
                response_deserializer=gateway_dot_account__pb2.Account.FromString,
                )
        self.DeleteAccount = channel.unary_unary(
                '/gateway.Gateway/DeleteAccount',
                request_serializer=gateway_dot_account__pb2.DeleteAccountRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateBatchJob = channel.unary_unary(
                '/gateway.Gateway/CreateBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.CreateBatchJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.BatchJob.FromString,
                )
        self.GetBatchJob = channel.unary_unary(
                '/gateway.Gateway/GetBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.GetBatchJobRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.BatchJob.FromString,
                )
        self.ListBatchJobs = channel.unary_unary(
                '/gateway.Gateway/ListBatchJobs',
                request_serializer=gateway_dot_batch__job__pb2.ListBatchJobsRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.ListBatchJobsResponse.FromString,
                )
        self.DeleteBatchJob = channel.unary_unary(
                '/gateway.Gateway/DeleteBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.DeleteBatchJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.BatchDeleteBatchJobs = channel.unary_unary(
                '/gateway.Gateway/BatchDeleteBatchJobs',
                request_serializer=gateway_dot_batch__job__pb2.BatchDeleteBatchJobsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CancelBatchJob = channel.unary_unary(
                '/gateway.Gateway/CancelBatchJob',
                request_serializer=gateway_dot_batch__job__pb2.CancelBatchJobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateCluster = channel.unary_unary(
                '/gateway.Gateway/CreateCluster',
                request_serializer=gateway_dot_cluster__pb2.CreateClusterRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.Cluster.FromString,
                )
        self.GetCluster = channel.unary_unary(
                '/gateway.Gateway/GetCluster',
                request_serializer=gateway_dot_cluster__pb2.GetClusterRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.Cluster.FromString,
                )
        self.ListClusters = channel.unary_unary(
                '/gateway.Gateway/ListClusters',
                request_serializer=gateway_dot_cluster__pb2.ListClustersRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.ListClustersResponse.FromString,
                )
        self.UpdateCluster = channel.unary_unary(
                '/gateway.Gateway/UpdateCluster',
                request_serializer=gateway_dot_cluster__pb2.UpdateClusterRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.Cluster.FromString,
                )
        self.DeleteCluster = channel.unary_unary(
                '/gateway.Gateway/DeleteCluster',
                request_serializer=gateway_dot_cluster__pb2.DeleteClusterRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetClusterConnectionInfo = channel.unary_unary(
                '/gateway.Gateway/GetClusterConnectionInfo',
                request_serializer=gateway_dot_cluster__pb2.GetClusterConnectionInfoRequest.SerializeToString,
                response_deserializer=gateway_dot_cluster__pb2.ClusterConnectionInfo.FromString,
                )
        self.CreateEnvironment = channel.unary_unary(
                '/gateway.Gateway/CreateEnvironment',
                request_serializer=gateway_dot_environment__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.Environment.FromString,
                )
        self.GetEnvironment = channel.unary_unary(
                '/gateway.Gateway/GetEnvironment',
                request_serializer=gateway_dot_environment__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.Environment.FromString,
                )
        self.ListEnvironments = channel.unary_unary(
                '/gateway.Gateway/ListEnvironments',
                request_serializer=gateway_dot_environment__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.ListEnvironmentsResponse.FromString,
                )
        self.UpdateEnvironment = channel.unary_unary(
                '/gateway.Gateway/UpdateEnvironment',
                request_serializer=gateway_dot_environment__pb2.UpdateEnvironmentRequest.SerializeToString,
                response_deserializer=gateway_dot_environment__pb2.Environment.FromString,
                )
        self.DeleteEnvironment = channel.unary_unary(
                '/gateway.Gateway/DeleteEnvironment',
                request_serializer=gateway_dot_environment__pb2.DeleteEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.BatchDeleteEnvironments = channel.unary_unary(
                '/gateway.Gateway/BatchDeleteEnvironments',
                request_serializer=gateway_dot_environment__pb2.BatchDeleteEnvironmentsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ConnectEnvironment = channel.unary_unary(
                '/gateway.Gateway/ConnectEnvironment',
                request_serializer=gateway_dot_environment__pb2.ConnectEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DisconnectEnvironment = channel.unary_unary(
                '/gateway.Gateway/DisconnectEnvironment',
                request_serializer=gateway_dot_environment__pb2.DisconnectEnvironmentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetSnapshot = channel.unary_unary(
                '/gateway.Gateway/GetSnapshot',
                request_serializer=gateway_dot_snapshot__pb2.GetSnapshotRequest.SerializeToString,
                response_deserializer=gateway_dot_snapshot__pb2.Snapshot.FromString,
                )
        self.ListSnapshots = channel.unary_unary(
                '/gateway.Gateway/ListSnapshots',
                request_serializer=gateway_dot_snapshot__pb2.ListSnapshotsRequest.SerializeToString,
                response_deserializer=gateway_dot_snapshot__pb2.ListSnapshotsResponse.FromString,
                )
        self.GetBatchJobLogs = channel.unary_unary(
                '/gateway.Gateway/GetBatchJobLogs',
                request_serializer=gateway_dot_batch__job__pb2.GetBatchJobLogsRequest.SerializeToString,
                response_deserializer=gateway_dot_batch__job__pb2.GetBatchJobLogsResponse.FromString,
                )
        self.CreateNodePool = channel.unary_unary(
                '/gateway.Gateway/CreateNodePool',
                request_serializer=gateway_dot_node__pool__pb2.CreateNodePoolRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePool.FromString,
                )
        self.GetNodePool = channel.unary_unary(
                '/gateway.Gateway/GetNodePool',
                request_serializer=gateway_dot_node__pool__pb2.GetNodePoolRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePool.FromString,
                )
        self.ListNodePools = channel.unary_unary(
                '/gateway.Gateway/ListNodePools',
                request_serializer=gateway_dot_node__pool__pb2.ListNodePoolsRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.ListNodePoolsResponse.FromString,
                )
        self.UpdateNodePool = channel.unary_unary(
                '/gateway.Gateway/UpdateNodePool',
                request_serializer=gateway_dot_node__pool__pb2.UpdateNodePoolRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePool.FromString,
                )
        self.DeleteNodePool = channel.unary_unary(
                '/gateway.Gateway/DeleteNodePool',
                request_serializer=gateway_dot_node__pool__pb2.DeleteNodePoolRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.BatchDeleteNodePools = channel.unary_unary(
                '/gateway.Gateway/BatchDeleteNodePools',
                request_serializer=gateway_dot_node__pool__pb2.BatchDeleteNodePoolsRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetNodePoolStats = channel.unary_unary(
                '/gateway.Gateway/GetNodePoolStats',
                request_serializer=gateway_dot_node__pool__pb2.GetNodePoolStatsRequest.SerializeToString,
                response_deserializer=gateway_dot_node__pool__pb2.NodePoolStats.FromString,
                )
        self.CreateUser = channel.unary_unary(
                '/gateway.Gateway/CreateUser',
                request_serializer=gateway_dot_user__pb2.CreateUserRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.User.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/gateway.Gateway/GetUser',
                request_serializer=gateway_dot_user__pb2.GetUserRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.User.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/gateway.Gateway/ListUsers',
                request_serializer=gateway_dot_user__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.ListUsersResponse.FromString,
                )
        self.UpdateUser = channel.unary_unary(
                '/gateway.Gateway/UpdateUser',
                request_serializer=gateway_dot_user__pb2.UpdateUserRequest.SerializeToString,
                response_deserializer=gateway_dot_user__pb2.User.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/gateway.Gateway/DeleteUser',
                request_serializer=gateway_dot_user__pb2.DeleteUserRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateModel = channel.unary_unary(
                '/gateway.Gateway/CreateModel',
                request_serializer=gateway_dot_model__pb2.CreateModelRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.Model.FromString,
                )
        self.GetModel = channel.unary_unary(
                '/gateway.Gateway/GetModel',
                request_serializer=gateway_dot_model__pb2.GetModelRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.Model.FromString,
                )
        self.ListModels = channel.unary_unary(
                '/gateway.Gateway/ListModels',
                request_serializer=gateway_dot_model__pb2.ListModelsRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.ListModelsResponse.FromString,
                )
        self.UpdateModel = channel.unary_unary(
                '/gateway.Gateway/UpdateModel',
                request_serializer=gateway_dot_model__pb2.UpdateModelRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.Model.FromString,
                )
        self.DeleteModel = channel.unary_unary(
                '/gateway.Gateway/DeleteModel',
                request_serializer=gateway_dot_model__pb2.DeleteModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetModelUploadEndpoint = channel.unary_unary(
                '/gateway.Gateway/GetModelUploadEndpoint',
                request_serializer=gateway_dot_model__pb2.GetModelUploadEndpointRequest.SerializeToString,
                response_deserializer=gateway_dot_model__pb2.GetModelUploadEndpointResponse.FromString,
                )
        self.ValidateModelUpload = channel.unary_unary(
                '/gateway.Gateway/ValidateModelUpload',
                request_serializer=gateway_dot_model__pb2.ValidateModelUploadRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeployModel = channel.unary_unary(
                '/gateway.Gateway/DeployModel',
                request_serializer=gateway_dot_model__pb2.DeployModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UndeployModel = channel.unary_unary(
                '/gateway.Gateway/UndeployModel',
                request_serializer=gateway_dot_model__pb2.UndeployModelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateDeployment = channel.unary_unary(
                '/gateway.Gateway/CreateDeployment',
                request_serializer=gateway_dot_deployment__pb2.CreateDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                )
        self.GetDeployment = channel.unary_unary(
                '/gateway.Gateway/GetDeployment',
                request_serializer=gateway_dot_deployment__pb2.GetDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                )
        self.StartDeployment = channel.unary_unary(
                '/gateway.Gateway/StartDeployment',
                request_serializer=gateway_dot_deployment__pb2.StartDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                )
        self.ListDeployments = channel.unary_unary(
                '/gateway.Gateway/ListDeployments',
                request_serializer=gateway_dot_deployment__pb2.ListDeploymentsRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.ListDeploymentsResponse.FromString,
                )
        self.UpdateDeployment = channel.unary_unary(
                '/gateway.Gateway/UpdateDeployment',
                request_serializer=gateway_dot_deployment__pb2.UpdateDeploymentRequest.SerializeToString,
                response_deserializer=gateway_dot_deployment__pb2.Deployment.FromString,
                )
        self.DeleteDeployment = channel.unary_unary(
                '/gateway.Gateway/DeleteDeployment',
                request_serializer=gateway_dot_deployment__pb2.DeleteDeploymentRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateAwsIamRoleBinding = channel.unary_unary(
                '/gateway.Gateway/CreateAwsIamRoleBinding',
                request_serializer=gateway_dot_aws__iam__role__binding__pb2.CreateAwsIamRoleBindingRequest.SerializeToString,
                response_deserializer=gateway_dot_aws__iam__role__binding__pb2.AwsIamRoleBinding.FromString,
                )
        self.ListAwsIamRoleBindings = channel.unary_unary(
                '/gateway.Gateway/ListAwsIamRoleBindings',
                request_serializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsRequest.SerializeToString,
                response_deserializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsResponse.FromString,
                )
        self.DeleteAwsIamRoleBinding = channel.unary_unary(
                '/gateway.Gateway/DeleteAwsIamRoleBinding',
                request_serializer=gateway_dot_aws__iam__role__binding__pb2.DeleteAwsIamRoleBindingRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReconcileCluster = channel.unary_unary(
                '/gateway.Gateway/ReconcileCluster',
                request_serializer=gateway_dot_cluster__pb2.ReconcileClusterRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ReconcileNodePool = channel.unary_unary(
                '/gateway.Gateway/ReconcileNodePool',
                request_serializer=gateway_dot_node__pool__pb2.ReconcileNodePoolRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class GatewayServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SignIn(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOAuthArguments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount(self, request, context):
        """CRUD APIs for accounts.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateBatchJob(self, request, context):
        """CRUD APIs for batch jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBatchJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBatchJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDeleteBatchJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelBatchJob(self, request, context):
        """Cancels an existing batch job if it is queued, pending, or running.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCluster(self, request, context):
        """CRUD APIs for clusters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClusters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCluster(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterConnectionInfo(self, request, context):
        """Retrieve connection settings for the cluster to be put in kubeconfig
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateEnvironment(self, request, context):
        """CRUD APIs for environments.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDeleteEnvironments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectEnvironment(self, request, context):
        """Connects the environment to a node pool.
        Returns an error if there is an existing pending connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisconnectEnvironment(self, request, context):
        """Disconnects the environment from the node pool. Returns an error
        if the environment is not connected to a node pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSnapshot(self, request, context):
        """CRUD APIs for snapshots.
        TODO: Add the other CRUD APIs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSnapshots(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatchJobLogs(self, request, context):
        """Retrieve logs for the batch job.
        TODO: add pagination/streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNodePool(self, request, context):
        """CRUD APIs for node pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodePool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodePools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNodePool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNodePool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchDeleteNodePools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodePoolStats(self, request, context):
        """Returns node pool stats.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateUser(self, request, context):
        """CRUD APIs for users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModel(self, request, context):
        """CRUD APIs for models.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelUploadEndpoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateModelUpload(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDeployment(self, request, context):
        """CRUD APIs for deployments.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeployments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAwsIamRoleBinding(self, request, context):
        """CRUD APIs for AWS IAM role bindings.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAwsIamRoleBindings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAwsIamRoleBinding(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconcileCluster(self, request, context):
        """Admin-only calls to re-run steps of cluster or node pool creation. Useful for upgrades of the existing clusters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReconcileNodePool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GatewayServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SignIn': grpc.unary_unary_rpc_method_handler(
                    servicer.SignIn,
                    request_deserializer=gateway_dot_sign__in__pb2.SignInRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetOAuthArguments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOAuthArguments,
                    request_deserializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsRequest.FromString,
                    response_serializer=gateway_dot_sign__in__pb2.GetOAuthArgumentsResponse.SerializeToString,
            ),
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=gateway_dot_account__pb2.CreateAccountRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.Account.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=gateway_dot_account__pb2.GetAccountRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.Account.SerializeToString,
            ),
            'ListAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccounts,
                    request_deserializer=gateway_dot_account__pb2.ListAccountsRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.ListAccountsResponse.SerializeToString,
            ),
            'UpdateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount,
                    request_deserializer=gateway_dot_account__pb2.UpdateAccountRequest.FromString,
                    response_serializer=gateway_dot_account__pb2.Account.SerializeToString,
            ),
            'DeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccount,
                    request_deserializer=gateway_dot_account__pb2.DeleteAccountRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.CreateBatchJobRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.BatchJob.SerializeToString,
            ),
            'GetBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.GetBatchJobRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.BatchJob.SerializeToString,
            ),
            'ListBatchJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBatchJobs,
                    request_deserializer=gateway_dot_batch__job__pb2.ListBatchJobsRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.ListBatchJobsResponse.SerializeToString,
            ),
            'DeleteBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.DeleteBatchJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchDeleteBatchJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDeleteBatchJobs,
                    request_deserializer=gateway_dot_batch__job__pb2.BatchDeleteBatchJobsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CancelBatchJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelBatchJob,
                    request_deserializer=gateway_dot_batch__job__pb2.CancelBatchJobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCluster,
                    request_deserializer=gateway_dot_cluster__pb2.CreateClusterRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'GetCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCluster,
                    request_deserializer=gateway_dot_cluster__pb2.GetClusterRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'ListClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClusters,
                    request_deserializer=gateway_dot_cluster__pb2.ListClustersRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.ListClustersResponse.SerializeToString,
            ),
            'UpdateCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCluster,
                    request_deserializer=gateway_dot_cluster__pb2.UpdateClusterRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'DeleteCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCluster,
                    request_deserializer=gateway_dot_cluster__pb2.DeleteClusterRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetClusterConnectionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterConnectionInfo,
                    request_deserializer=gateway_dot_cluster__pb2.GetClusterConnectionInfoRequest.FromString,
                    response_serializer=gateway_dot_cluster__pb2.ClusterConnectionInfo.SerializeToString,
            ),
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.Environment.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.Environment.SerializeToString,
            ),
            'ListEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironments,
                    request_deserializer=gateway_dot_environment__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'UpdateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.UpdateEnvironmentRequest.FromString,
                    response_serializer=gateway_dot_environment__pb2.Environment.SerializeToString,
            ),
            'DeleteEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.DeleteEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchDeleteEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDeleteEnvironments,
                    request_deserializer=gateway_dot_environment__pb2.BatchDeleteEnvironmentsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ConnectEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.ConnectEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DisconnectEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.DisconnectEnvironment,
                    request_deserializer=gateway_dot_environment__pb2.DisconnectEnvironmentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetSnapshot': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSnapshot,
                    request_deserializer=gateway_dot_snapshot__pb2.GetSnapshotRequest.FromString,
                    response_serializer=gateway_dot_snapshot__pb2.Snapshot.SerializeToString,
            ),
            'ListSnapshots': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSnapshots,
                    request_deserializer=gateway_dot_snapshot__pb2.ListSnapshotsRequest.FromString,
                    response_serializer=gateway_dot_snapshot__pb2.ListSnapshotsResponse.SerializeToString,
            ),
            'GetBatchJobLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatchJobLogs,
                    request_deserializer=gateway_dot_batch__job__pb2.GetBatchJobLogsRequest.FromString,
                    response_serializer=gateway_dot_batch__job__pb2.GetBatchJobLogsResponse.SerializeToString,
            ),
            'CreateNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.CreateNodePoolRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePool.SerializeToString,
            ),
            'GetNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.GetNodePoolRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePool.SerializeToString,
            ),
            'ListNodePools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodePools,
                    request_deserializer=gateway_dot_node__pool__pb2.ListNodePoolsRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.ListNodePoolsResponse.SerializeToString,
            ),
            'UpdateNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.UpdateNodePoolRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePool.SerializeToString,
            ),
            'DeleteNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.DeleteNodePoolRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'BatchDeleteNodePools': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchDeleteNodePools,
                    request_deserializer=gateway_dot_node__pool__pb2.BatchDeleteNodePoolsRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetNodePoolStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodePoolStats,
                    request_deserializer=gateway_dot_node__pool__pb2.GetNodePoolStatsRequest.FromString,
                    response_serializer=gateway_dot_node__pool__pb2.NodePoolStats.SerializeToString,
            ),
            'CreateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUser,
                    request_deserializer=gateway_dot_user__pb2.CreateUserRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.User.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=gateway_dot_user__pb2.GetUserRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.User.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=gateway_dot_user__pb2.ListUsersRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.ListUsersResponse.SerializeToString,
            ),
            'UpdateUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUser,
                    request_deserializer=gateway_dot_user__pb2.UpdateUserRequest.FromString,
                    response_serializer=gateway_dot_user__pb2.User.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=gateway_dot_user__pb2.DeleteUserRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModel,
                    request_deserializer=gateway_dot_model__pb2.CreateModelRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.Model.SerializeToString,
            ),
            'GetModel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModel,
                    request_deserializer=gateway_dot_model__pb2.GetModelRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.Model.SerializeToString,
            ),
            'ListModels': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModels,
                    request_deserializer=gateway_dot_model__pb2.ListModelsRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.ListModelsResponse.SerializeToString,
            ),
            'UpdateModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModel,
                    request_deserializer=gateway_dot_model__pb2.UpdateModelRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.Model.SerializeToString,
            ),
            'DeleteModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModel,
                    request_deserializer=gateway_dot_model__pb2.DeleteModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetModelUploadEndpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelUploadEndpoint,
                    request_deserializer=gateway_dot_model__pb2.GetModelUploadEndpointRequest.FromString,
                    response_serializer=gateway_dot_model__pb2.GetModelUploadEndpointResponse.SerializeToString,
            ),
            'ValidateModelUpload': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateModelUpload,
                    request_deserializer=gateway_dot_model__pb2.ValidateModelUploadRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployModel,
                    request_deserializer=gateway_dot_model__pb2.DeployModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UndeployModel': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployModel,
                    request_deserializer=gateway_dot_model__pb2.UndeployModelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.CreateDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'GetDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.GetDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'StartDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.StartDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.StartDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'ListDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeployments,
                    request_deserializer=gateway_dot_deployment__pb2.ListDeploymentsRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.ListDeploymentsResponse.SerializeToString,
            ),
            'UpdateDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.UpdateDeploymentRequest.FromString,
                    response_serializer=gateway_dot_deployment__pb2.Deployment.SerializeToString,
            ),
            'DeleteDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDeployment,
                    request_deserializer=gateway_dot_deployment__pb2.DeleteDeploymentRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateAwsIamRoleBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAwsIamRoleBinding,
                    request_deserializer=gateway_dot_aws__iam__role__binding__pb2.CreateAwsIamRoleBindingRequest.FromString,
                    response_serializer=gateway_dot_aws__iam__role__binding__pb2.AwsIamRoleBinding.SerializeToString,
            ),
            'ListAwsIamRoleBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAwsIamRoleBindings,
                    request_deserializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsRequest.FromString,
                    response_serializer=gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsResponse.SerializeToString,
            ),
            'DeleteAwsIamRoleBinding': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAwsIamRoleBinding,
                    request_deserializer=gateway_dot_aws__iam__role__binding__pb2.DeleteAwsIamRoleBindingRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReconcileCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconcileCluster,
                    request_deserializer=gateway_dot_cluster__pb2.ReconcileClusterRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ReconcileNodePool': grpc.unary_unary_rpc_method_handler(
                    servicer.ReconcileNodePool,
                    request_deserializer=gateway_dot_node__pool__pb2.ReconcileNodePoolRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'gateway.Gateway', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Gateway(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SignIn(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/SignIn',
            gateway_dot_sign__in__pb2.SignInRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOAuthArguments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetOAuthArguments',
            gateway_dot_sign__in__pb2.GetOAuthArgumentsRequest.SerializeToString,
            gateway_dot_sign__in__pb2.GetOAuthArgumentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateAccount',
            gateway_dot_account__pb2.CreateAccountRequest.SerializeToString,
            gateway_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetAccount',
            gateway_dot_account__pb2.GetAccountRequest.SerializeToString,
            gateway_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListAccounts',
            gateway_dot_account__pb2.ListAccountsRequest.SerializeToString,
            gateway_dot_account__pb2.ListAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateAccount',
            gateway_dot_account__pb2.UpdateAccountRequest.SerializeToString,
            gateway_dot_account__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteAccount',
            gateway_dot_account__pb2.DeleteAccountRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateBatchJob',
            gateway_dot_batch__job__pb2.CreateBatchJobRequest.SerializeToString,
            gateway_dot_batch__job__pb2.BatchJob.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetBatchJob',
            gateway_dot_batch__job__pb2.GetBatchJobRequest.SerializeToString,
            gateway_dot_batch__job__pb2.BatchJob.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListBatchJobs',
            gateway_dot_batch__job__pb2.ListBatchJobsRequest.SerializeToString,
            gateway_dot_batch__job__pb2.ListBatchJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteBatchJob',
            gateway_dot_batch__job__pb2.DeleteBatchJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchDeleteBatchJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/BatchDeleteBatchJobs',
            gateway_dot_batch__job__pb2.BatchDeleteBatchJobsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelBatchJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CancelBatchJob',
            gateway_dot_batch__job__pb2.CancelBatchJobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateCluster',
            gateway_dot_cluster__pb2.CreateClusterRequest.SerializeToString,
            gateway_dot_cluster__pb2.Cluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetCluster',
            gateway_dot_cluster__pb2.GetClusterRequest.SerializeToString,
            gateway_dot_cluster__pb2.Cluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListClusters',
            gateway_dot_cluster__pb2.ListClustersRequest.SerializeToString,
            gateway_dot_cluster__pb2.ListClustersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateCluster',
            gateway_dot_cluster__pb2.UpdateClusterRequest.SerializeToString,
            gateway_dot_cluster__pb2.Cluster.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteCluster',
            gateway_dot_cluster__pb2.DeleteClusterRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusterConnectionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetClusterConnectionInfo',
            gateway_dot_cluster__pb2.GetClusterConnectionInfoRequest.SerializeToString,
            gateway_dot_cluster__pb2.ClusterConnectionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateEnvironment',
            gateway_dot_environment__pb2.CreateEnvironmentRequest.SerializeToString,
            gateway_dot_environment__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetEnvironment',
            gateway_dot_environment__pb2.GetEnvironmentRequest.SerializeToString,
            gateway_dot_environment__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListEnvironments',
            gateway_dot_environment__pb2.ListEnvironmentsRequest.SerializeToString,
            gateway_dot_environment__pb2.ListEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateEnvironment',
            gateway_dot_environment__pb2.UpdateEnvironmentRequest.SerializeToString,
            gateway_dot_environment__pb2.Environment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteEnvironment',
            gateway_dot_environment__pb2.DeleteEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchDeleteEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/BatchDeleteEnvironments',
            gateway_dot_environment__pb2.BatchDeleteEnvironmentsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ConnectEnvironment',
            gateway_dot_environment__pb2.ConnectEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisconnectEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DisconnectEnvironment',
            gateway_dot_environment__pb2.DisconnectEnvironmentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetSnapshot',
            gateway_dot_snapshot__pb2.GetSnapshotRequest.SerializeToString,
            gateway_dot_snapshot__pb2.Snapshot.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSnapshots(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListSnapshots',
            gateway_dot_snapshot__pb2.ListSnapshotsRequest.SerializeToString,
            gateway_dot_snapshot__pb2.ListSnapshotsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatchJobLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetBatchJobLogs',
            gateway_dot_batch__job__pb2.GetBatchJobLogsRequest.SerializeToString,
            gateway_dot_batch__job__pb2.GetBatchJobLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateNodePool',
            gateway_dot_node__pool__pb2.CreateNodePoolRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePool.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetNodePool',
            gateway_dot_node__pool__pb2.GetNodePoolRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePool.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNodePools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListNodePools',
            gateway_dot_node__pool__pb2.ListNodePoolsRequest.SerializeToString,
            gateway_dot_node__pool__pb2.ListNodePoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateNodePool',
            gateway_dot_node__pool__pb2.UpdateNodePoolRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePool.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteNodePool',
            gateway_dot_node__pool__pb2.DeleteNodePoolRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchDeleteNodePools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/BatchDeleteNodePools',
            gateway_dot_node__pool__pb2.BatchDeleteNodePoolsRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNodePoolStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetNodePoolStats',
            gateway_dot_node__pool__pb2.GetNodePoolStatsRequest.SerializeToString,
            gateway_dot_node__pool__pb2.NodePoolStats.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateUser',
            gateway_dot_user__pb2.CreateUserRequest.SerializeToString,
            gateway_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetUser',
            gateway_dot_user__pb2.GetUserRequest.SerializeToString,
            gateway_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListUsers',
            gateway_dot_user__pb2.ListUsersRequest.SerializeToString,
            gateway_dot_user__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateUser',
            gateway_dot_user__pb2.UpdateUserRequest.SerializeToString,
            gateway_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteUser',
            gateway_dot_user__pb2.DeleteUserRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateModel',
            gateway_dot_model__pb2.CreateModelRequest.SerializeToString,
            gateway_dot_model__pb2.Model.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetModel',
            gateway_dot_model__pb2.GetModelRequest.SerializeToString,
            gateway_dot_model__pb2.Model.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListModels',
            gateway_dot_model__pb2.ListModelsRequest.SerializeToString,
            gateway_dot_model__pb2.ListModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateModel',
            gateway_dot_model__pb2.UpdateModelRequest.SerializeToString,
            gateway_dot_model__pb2.Model.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteModel',
            gateway_dot_model__pb2.DeleteModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelUploadEndpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetModelUploadEndpoint',
            gateway_dot_model__pb2.GetModelUploadEndpointRequest.SerializeToString,
            gateway_dot_model__pb2.GetModelUploadEndpointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateModelUpload(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ValidateModelUpload',
            gateway_dot_model__pb2.ValidateModelUploadRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeployModel',
            gateway_dot_model__pb2.DeployModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UndeployModel',
            gateway_dot_model__pb2.UndeployModelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateDeployment',
            gateway_dot_deployment__pb2.CreateDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/GetDeployment',
            gateway_dot_deployment__pb2.GetDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/StartDeployment',
            gateway_dot_deployment__pb2.StartDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListDeployments',
            gateway_dot_deployment__pb2.ListDeploymentsRequest.SerializeToString,
            gateway_dot_deployment__pb2.ListDeploymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/UpdateDeployment',
            gateway_dot_deployment__pb2.UpdateDeploymentRequest.SerializeToString,
            gateway_dot_deployment__pb2.Deployment.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteDeployment',
            gateway_dot_deployment__pb2.DeleteDeploymentRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAwsIamRoleBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/CreateAwsIamRoleBinding',
            gateway_dot_aws__iam__role__binding__pb2.CreateAwsIamRoleBindingRequest.SerializeToString,
            gateway_dot_aws__iam__role__binding__pb2.AwsIamRoleBinding.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAwsIamRoleBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ListAwsIamRoleBindings',
            gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsRequest.SerializeToString,
            gateway_dot_aws__iam__role__binding__pb2.ListAwsIamRoleBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAwsIamRoleBinding(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/DeleteAwsIamRoleBinding',
            gateway_dot_aws__iam__role__binding__pb2.DeleteAwsIamRoleBindingRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReconcileCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ReconcileCluster',
            gateway_dot_cluster__pb2.ReconcileClusterRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReconcileNodePool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/gateway.Gateway/ReconcileNodePool',
            gateway_dot_node__pool__pb2.ReconcileNodePoolRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import List, Optional, Union
from .image_api import ImageToImageRequestBody, TextToImageRequestBody, TextPrompt

import fireworks.client
import httpx
from PIL import Image
import io
import copy
import os


class ImageInference:
    """
    Main client class for the Fireworks Image Generation API. Currently supports Stable Diffusion
    XL 1.0 (see https://huggingface.co/stabilityai/stable-diffusion-xl-base-1.0). This client
    supports both text-to-image and image-to-image generation.

    Attributes:
    - base_url (str): Base URL for the image generation API. Defaults to `fireworks.client.base_url`, which should
                      be set at initialization.
    - api_key (str): API key for authentication. Defaults to `fireworks.client.api_key`, which should be set at
                     initialization.
    """

    def __init__(self, base_url: Optional[str] = None, api_key: Optional[str] = None):
        self.base_url = base_url or fireworks.client.base_url
        self.api_key = api_key or fireworks.client.api_key

        self.client = httpx.Client()
        self.endpoint_base_uri = f"{self.base_url}/image_generation/stable_diffusion"
        self.headers = {
            "Authorization": f"Bearer {self.api_key}",
        }

    def text_to_image(
        self,
        prompt: str,
        negative_prompt: Optional[str] = None,
        cfg_scale: int = 7,
        clip_guidance_preset: str = "NONE",
        height: int = 1024,
        width: int = 1024,
        sampler: Optional[str] = None,
        samples: int = 1,
        steps: int = 50,
        seed: int = 0,
        style_preset: Optional[str] = None,
        model: str = "accounts/fireworks/models/stable-diffusion-xl-1024-v1-0",
    ) -> Union[Image.Image, List[Image.Image]]:
        """
        Generate an image or images based on the given text prompt and optional negative prompt.
        See the OpenAPI spec (https://readme.fireworks.ai/reference/post_image-generation-stable-diffusion)
        for the most up-to-date description of the supported parameters

        Parameters:
        - prompt (str): The main text prompt based on which the image will be generated.
        - negative_prompt (str, optional): A secondary text prompt which can be used to guide the image generation in a negative way.
        - cfg_scale (int, optional): Configuration scale for the image generation. Defaults to 7.
        - clip_guidance_preset (str, optional): CLIP guidance preset. Defaults to "NONE".
        - height (int, optional): Desired height of the generated image. Defaults to 1024.
        - width (int, optional): Desired width of the generated image. Defaults to 1024.
        - sampler (str, optional): Sampler type. Optional.
        - samples (int, optional): Number of images to be generated. Defaults to 1.
        - steps (int, optional): Number of steps for the generation process. Defaults to 50.
        - seed (int, optional): Seed for random number generation. Defaults to 0.
        - style_preset (str, optional): Style preset for the generated image. Optional.
        - model (str, optional): which model to use. Defaults to "accounts/fireworks/models/stable-diffusion-xl-1024-v1-0".

        Returns:
        Image.Image or List[Image.Image]: Generated image or a list of generated images.

        Raises:
        RuntimeError: If there is an error in the image generation process.
        """
        text_prompts = [
            TextPrompt(text=prompt, weight=1.0),
        ]
        if negative_prompt:
            text_prompts.append(TextPrompt(text=negative_prompt, weight=-1.0))
        request_body = TextToImageRequestBody(
            cfg_scale=cfg_scale,
            clip_guidance_preset=clip_guidance_preset,
            height=height,
            width=width,
            sampler=sampler,
            samples=samples,
            steps=steps,
            seed=seed,
            style_preset=style_preset,
            text_prompts=text_prompts,
            model=model,
        )
        payload_dict = request_body.dict()
        headers_copy = copy.copy(self.headers)
        headers_copy["Content-Type"] = "application/json"
        if samples == 1:
            headers_copy["Accept"] = "image/png"
        else:
            headers_copy["Accept"] = "application/json"
        response = self.client.post(
            self.endpoint_base_uri, headers=headers_copy, json=payload_dict, timeout=300
        )
        if response.status_code == 200:
            if samples == 1:
                return Image.open(io.BytesIO(response.content))
            else:
                return [
                    Image.open(io.BytesIO(artifact.binary))
                    for artifact in response.json()["artifacts"]
                ]
        else:
            raise RuntimeError(
                f"Failed to generate image: HTTP {response.status_code}, {response.text}"
            )

    def image_to_image(
        self,
        init_image: Union[Image.Image, str, os.PathLike, bytes],
        prompt: str,
        negative_prompt: Optional[str] = None,
        cfg_scale: int = 7,
        clip_guidance_preset: str = "NONE",
        sampler: Optional[str] = None,
        samples: int = 1,
        steps: int = 50,
        seed: int = 0,
        style_preset: Optional[str] = None,
        init_image_mode: str = "IMAGE_STRENGTH",
        image_strength: Optional[float] = None,
        step_schedule_start: Optional[float] = 0.65,
        step_schedule_end: Optional[float] = None,
        model: str = "accounts/fireworks/models/stable-diffusion-xl-1024-v1-0",
        client_account_id_header: Optional[str] = None,
    ):
        """
        Modify an existing image based on a given text prompt and optional negative prompt.
        See the OpenAPI spec (https://readme.fireworks.ai/reference/post_image-generation-stable-diffusion)
        for the most up-to-date description of the supported parameters

        Parameters:
        - init_image (Union[Image.Image, str, os.PathLike, bytes]): Initial image to be modified. It can be provided as a PIL Image object, path to an image, or raw bytes.
        - prompt (str): The main text prompt based on which the image will be modified.
        - negative_prompt (str, optional): A secondary text prompt which can be used to guide the image modification in a negative way.
        - cfg_scale (int, optional): Configuration scale for the image modification. Defaults to 7.
        - clip_guidance_preset (str, optional): CLIP guidance preset. Defaults to "NONE".
        - sampler (str, optional): Sampler type. Optional.
        - samples (int, optional): Number of images to be generated. Defaults to 1.
        - steps (int, optional): Number of steps for the modification process. Defaults to 50.
        - seed (int, optional): Seed for random number generation. Defaults to 0.
        - style_preset (str, optional): Style preset for the modified image. Optional.
        - init_image_mode (str, optional): Initialization mode for the image modification. Defaults to "IMAGE_STRENGTH".
        - image_strength (float, optional): Strength of the initial image. Required when init_image_mode is "IMAGE_STRENGTH".
        - step_schedule_start (float, optional): Start of the step schedule. Required when init_image_mode is "STEP_SCHEDULE". Defaults to 0.65.
        - step_schedule_end (float, optional): End of the step schedule. Required when init_image_mode is "STEP_SCHEDULE".
        - model (str, optional): which model to use. Defaults to "accounts/fireworks/models/stable-diffusion-xl-1024-v1-0".
        - client_account_id_header (str, optional): Client account ID header. Used for private deployments. Optional.

        Returns:
        Image.Image or List[Image.Image]: Modified image or a list of modified images.

        Raises:
        ValueError: If required parameters are missing based on the given init_image_mode.
        RuntimeError: If there is an error in the image modification process.
        """
        # Argument Validation
        if init_image_mode == "IMAGE_STRENGTH" and image_strength is None:
            raise ValueError(
                "image_strength is required when init_image_mode is IMAGE_STRENGTH"
            )
        if init_image_mode == "STEP_SCHEDULE" and (
            step_schedule_start is None or step_schedule_end is None
        ):
            raise ValueError(
                "Both step_schedule_start and step_schedule_end are required when init_image_mode is STEP_SCHEDULE"
            )

        # Construct and validate request fields.
        # NB: prompt and init_image are not used here. Instead, we construct
        # them specially to be sent as multipart/form-data
        request_body = ImageToImageRequestBody(
            cfg_scale=cfg_scale,
            clip_guidance_preset=clip_guidance_preset,
            sampler=sampler,
            samples=samples,
            steps=steps,
            seed=seed,
            style_preset=style_preset,
            init_image_mode=init_image_mode,
            image_strength=image_strength,
            step_schedule_start=step_schedule_start,
            step_schedule_end=step_schedule_end,
            model=model,
        )
        payload_dict = request_body.dict()

        # Special fields
        payload_dict["text_prompts[0][text]"] = prompt
        payload_dict["text_prompts[0][weight]"] = 1.0
        if negative_prompt:
            payload_dict["text_prompts[1][text]"] = negative_prompt
            payload_dict["text_prompts[1][weight]"] = -1.0

        headers_copy = copy.copy(self.headers)
        if samples == 1:
            headers_copy["Accept"] = "image/png"
        else:
            headers_copy["Accept"] = "application/json"

        if client_account_id_header:
            headers_copy["X-Fireworks-Routing-Account-ID"] = client_account_id_header

        # Normalize all forms of `init_image` into a `bytes` object
        # to send over the wire
        if isinstance(init_image, Image.Image):
            img_bio = io.BytesIO()
            init_image.save(img_bio, format="PNG")
            init_image = img_bio.getvalue()
        elif isinstance(init_image, (str, os.PathLike)):
            with open(init_image, "rb") as f:
                init_image = f.read()

        files = {
            "init_image": init_image,
        }
        response = self.client.post(
            f"{self.endpoint_base_uri}/image_to_image",
            headers=headers_copy,
            data=payload_dict,
            files=files,
            timeout=300,
        )
        if response.status_code == 200:
            if samples == 1:
                return Image.open(io.BytesIO(response.content))
            else:
                return [
                    Image.open(io.BytesIO(artifact.binary))
                    for artifact in response.json()["artifacts"]
                ]
        else:
            raise RuntimeError(
                f"Failed to generate image: HTTP {response.status_code}, {response.text}"
            )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gateway/status.proto\x12\x07gateway\"6\n\x06Status\x12\x1b\n\x04\x63ode\x18\x01 \x01(\x0e\x32\r.gateway.Code\x12\x0f\n\x07message\x18\x02 \x01(\t*\xb7\x02\n\x04\x43ode\x12\x06\n\x02OK\x10\x00\x12\r\n\tCANCELLED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x42\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _CODE._serialized_start=90
  _CODE._serialized_end=401
  _STATUS._serialized_start=33
  _STATUS._serialized_end=87
# @@protoc_insertion_point(module_scope)



from pydantic import BaseModel, Field
from typing import Optional, List, Literal, Dict


class LogProbs(BaseModel):
    text_offset: List[int] = Field(default_factory=list)
    token_logprobs: List[float] = Field(default_factory=list)
    tokens: List[str] = Field(default_factory=list)
    top_logprobs: Optional[List[Dict[str, float]]] = Field(default_factory=list)


class UsageInfo(BaseModel):
    """Usage statistics.

    Attributes:
      prompt_tokens (int): The number of tokens in the prompt.
      total_tokens (int): The total number of tokens used in the request (prompt + completion).
      completion_tokens (Optional[int]): The number of tokens in the generated completion.
    """

    prompt_tokens: int
    total_tokens: int
    completion_tokens: Optional[int] = None


class Choice(BaseModel):
    """A completion choice.

    Attributes:
      index (int): The index of the completion choice.
      text (str): The completion response.
      logprobs (float, optional): The log probabilities of the most likely tokens.
      finish_reason (str): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    text: str
    logprobs: Optional[LogProbs] = None
    finish_reason: Optional[Literal["stop", "length", "error"]] = None


class CompletionResponse(BaseModel):
    """The response message from a /v1/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "text_completion".
      created (int): The Unix time in seconds when the response was generated.
      choices (List[Choice]): The list of generated completion choices.
    """

    id: str
    object: str
    created: int
    model: str
    choices: List[Choice]
    usage: UsageInfo


class CompletionResponseStreamChoice(BaseModel):
    """A streamed completion choice.

    Attributes:
      index (int): The index of the completion choice.
      text (str): The completion response.
      logprobs (float, optional): The log probabilities of the most likely tokens.
      finish_reason (str): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    text: str
    logprobs: Optional[LogProbs] = None
    finish_reason: Optional[Literal["stop", "length", "error"]] = None


class CompletionStreamResponse(BaseModel):
    """The streamed response message from a /v1/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "text_completion".
      created (int): The Unix time in seconds when the response was generated.
      model (str): The model used for the chat completion.
      choices (List[CompletionResponseStreamChoice]):
        The list of streamed completion choices.
    """

    id: str
    object: str
    created: int
    model: str
    choices: List[CompletionResponseStreamChoice]
    usage: Optional[UsageInfo] = None


class Model(BaseModel):
    """A model deployed to the Fireworks platform.

    Attributes:
      id (str): The model name.
      object (str): The object type, which is always "model".
      created (int): The Unix time in seconds when the model was generated.
    """

    id: str
    object: str
    created: int


class ListModelsResponse(BaseModel):
    """The response message from a /v1/models call.

    Attributes:
      object (str): The object type, which is always "list".
      data (List[Model]): The list of models.
    """

    object: str
    data: List[Model]


class ChatMessage(BaseModel):
    """A chat completion message.

    Attributes:
      role (str): The role of the author of this message.
      content (str): The contents of the message.
    """

    role: str
    content: str


class ChatCompletionResponseChoice(BaseModel):
    """A chat completion choice generated by a chat model.

    Attributes:
      index (int): The index of the chat completion choice.
      message (ChatMessage): The chat completion message.
      finish_reason (Optional[str]): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    message: ChatMessage
    finish_reason: Optional[str] = None


class ChatCompletionResponse(BaseModel):
    """The response message from a /v1/chat/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "chat.completion".
      created (int): The Unix time in seconds when the response was generated.
      model (str): The model used for the chat completion.
      choices (List[ChatCompletionResponseChoice]): The list of chat completion choices.
      usage (UsageInfo): Usage statistics for the chat completion.
    """

    id: str
    object: str
    created: int
    model: str
    choices: List[ChatCompletionResponseChoice]
    usage: Optional[UsageInfo] = None


class DeltaMessage(BaseModel):
    """A message delta.

    Attributes:
      role (str): The role of the author of this message.
      content (str): The contents of the chunk message.
    """

    role: Optional[str] = None
    content: Optional[str] = None


class ChatCompletionResponseStreamChoice(BaseModel):
    """A streamed chat completion choice.

    Attributes:
      index (int): The index of the chat completion choice.
      delta (DeltaMessage): The message delta.
      finish_reason (str): The reason the model stopped generating tokens. This will be "stop" if
        the model hit a natural stop point or a provided stop sequence, or
        "length" if the maximum number of tokens specified in the request was
        reached.
    """

    index: int
    delta: DeltaMessage
    finish_reason: Optional[Literal["stop", "length"]] = None


class ChatCompletionStreamResponse(BaseModel):
    """The streamed response message from a /v1/chat/completions call.

    Attributes:
      id (str): A unique identifier of the response.
      object (str): The object type, which is always "chat.completion".
      created (int): The Unix time in seconds when the response was generated.
      model (str): The model used for the chat completion.
      choices (List[ChatCompletionResponseStreamChoice]):
        The list of streamed chat completion choices.
    """

    id: str
    object: str
    created: int
    model: str
    choices: List[ChatCompletionResponseStreamChoice]
    usage: Optional[UsageInfo] = None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15gateway/cluster.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdb\x04\n\x07\x43luster\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x06 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12*\n\x0bgke_cluster\x18\x02 \x01(\x0b\x32\x13.gateway.GkeClusterH\x00\x12*\n\x0b\x65ks_cluster\x18\x07 \x01(\x0b\x32\x13.gateway.EksClusterH\x00\x12,\n\x0c\x66\x61ke_cluster\x18\x03 \x01(\x0b\x32\x14.gateway.FakeClusterH\x00\x12\x34\n\x10minikube_cluster\x18\x04 \x01(\x0b\x32\x18.gateway.MinikubeClusterH\x00\x12;\n\x0b\x61nnotations\x18\n \x03(\x0b\x32!.gateway.Cluster.AnnotationsEntryB\x03\xe0\x41\x01\x12-\n\x05state\x18\x05 \x01(\x0e\x32\x16.gateway.Cluster.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x08 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x0e\n\x0c\x63luster_type\"\xa4\x01\n\nGkeCluster\x12\x1a\n\nproject_id\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x18\n\x08location\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1c\n\x0c\x63luster_name\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rrepository_id\x18\x05 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13storage_bucket_name\x18\x06 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"\xfa\x02\n\nEksCluster\x12\x1e\n\x0e\x61ws_account_id\x18\t \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12&\n\x16\x66ireworks_manager_role\x18\x01 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x16\n\x06region\x18\x02 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x1c\n\x0c\x63luster_role\x18\x04 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\'\n\x17\x63luster_autoscaler_role\x18\n \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12 \n\x10system_node_role\x18\x07 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1a\n\nsubnet_ids\x18\x05 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1c\n\x0c\x63luster_name\x18\x03 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1f\n\x0frepository_name\x18\x06 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13storage_bucket_name\x18\x08 \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\x12#\n\x13node_security_group\x18\x0b \x01(\tB\x06\xe0\x41\x01\xe0\x41\x05\"!\n\x0fMinikubeCluster\x12\x0e\n\x06server\x18\x01 \x01(\t\"I\n\x0b\x46\x61keCluster\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\"l\n\x14\x43reateClusterRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12&\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x10.gateway.ClusterB\x03\xe0\x41\x02\x12\x17\n\ncluster_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"&\n\x11GetClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\",\n\x17ReconcileClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x87\x01\n\x13ListClustersRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"g\n\x14ListClustersResponse\x12\"\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x10.gateway.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\">\n\x14UpdateClusterRequest\x12&\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x10.gateway.ClusterB\x03\xe0\x41\x02\")\n\x14\x44\x65leteClusterRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"4\n\x1fGetClusterConnectionInfoRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\":\n\x15\x43lusterConnectionInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_data\x18\x02 \x01(\tB\x0cZ\n./;gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.cluster_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\n./;gateway'
  _CLUSTER_ANNOTATIONSENTRY._options = None
  _CLUSTER_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _CLUSTER.fields_by_name['name']._options = None
  _CLUSTER.fields_by_name['name']._serialized_options = b'\340A\003\340A\005'
  _CLUSTER.fields_by_name['display_name']._options = None
  _CLUSTER.fields_by_name['display_name']._serialized_options = b'\340A\001'
  _CLUSTER.fields_by_name['create_time']._options = None
  _CLUSTER.fields_by_name['create_time']._serialized_options = b'\340A\003\340A\005'
  _CLUSTER.fields_by_name['annotations']._options = None
  _CLUSTER.fields_by_name['annotations']._serialized_options = b'\340A\001'
  _CLUSTER.fields_by_name['state']._options = None
  _CLUSTER.fields_by_name['state']._serialized_options = b'\340A\003\340A\005'
  _CLUSTER.fields_by_name['status']._options = None
  _CLUSTER.fields_by_name['status']._serialized_options = b'\340A\003\340A\005'
  _GKECLUSTER.fields_by_name['project_id']._options = None
  _GKECLUSTER.fields_by_name['project_id']._serialized_options = b'\340A\002\340A\005'
  _GKECLUSTER.fields_by_name['location']._options = None
  _GKECLUSTER.fields_by_name['location']._serialized_options = b'\340A\002\340A\005'
  _GKECLUSTER.fields_by_name['cluster_name']._options = None
  _GKECLUSTER.fields_by_name['cluster_name']._serialized_options = b'\340A\001\340A\005'
  _GKECLUSTER.fields_by_name['repository_id']._options = None
  _GKECLUSTER.fields_by_name['repository_id']._serialized_options = b'\340A\001\340A\005'
  _GKECLUSTER.fields_by_name['storage_bucket_name']._options = None
  _GKECLUSTER.fields_by_name['storage_bucket_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['aws_account_id']._options = None
  _EKSCLUSTER.fields_by_name['aws_account_id']._serialized_options = b'\340A\002\340A\005'
  _EKSCLUSTER.fields_by_name['fireworks_manager_role']._options = None
  _EKSCLUSTER.fields_by_name['fireworks_manager_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['region']._options = None
  _EKSCLUSTER.fields_by_name['region']._serialized_options = b'\340A\002\340A\005'
  _EKSCLUSTER.fields_by_name['cluster_role']._options = None
  _EKSCLUSTER.fields_by_name['cluster_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['cluster_autoscaler_role']._options = None
  _EKSCLUSTER.fields_by_name['cluster_autoscaler_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['system_node_role']._options = None
  _EKSCLUSTER.fields_by_name['system_node_role']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['subnet_ids']._options = None
  _EKSCLUSTER.fields_by_name['subnet_ids']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['cluster_name']._options = None
  _EKSCLUSTER.fields_by_name['cluster_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['repository_name']._options = None
  _EKSCLUSTER.fields_by_name['repository_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['storage_bucket_name']._options = None
  _EKSCLUSTER.fields_by_name['storage_bucket_name']._serialized_options = b'\340A\001\340A\005'
  _EKSCLUSTER.fields_by_name['node_security_group']._options = None
  _EKSCLUSTER.fields_by_name['node_security_group']._serialized_options = b'\340A\001\340A\005'
  _CREATECLUSTERREQUEST.fields_by_name['parent']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _CREATECLUSTERREQUEST.fields_by_name['cluster']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['cluster']._serialized_options = b'\340A\002'
  _CREATECLUSTERREQUEST.fields_by_name['cluster_id']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['cluster_id']._serialized_options = b'\340A\002'
  _GETCLUSTERREQUEST.fields_by_name['name']._options = None
  _GETCLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _RECONCILECLUSTERREQUEST.fields_by_name['name']._options = None
  _RECONCILECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _LISTCLUSTERSREQUEST.fields_by_name['parent']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002'
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_size']._serialized_options = b'\340A\001'
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['page_token']._serialized_options = b'\340A\001'
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTCLUSTERSREQUEST.fields_by_name['order_by']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['order_by']._serialized_options = b'\340A\001'
  _UPDATECLUSTERREQUEST.fields_by_name['cluster']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['cluster']._serialized_options = b'\340A\002'
  _DELETECLUSTERREQUEST.fields_by_name['name']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _GETCLUSTERCONNECTIONINFOREQUEST.fields_by_name['name']._options = None
  _GETCLUSTERCONNECTIONINFOREQUEST.fields_by_name['name']._serialized_options = b'\340A\002'
  _CLUSTER._serialized_start=123
  _CLUSTER._serialized_end=726
  _CLUSTER_ANNOTATIONSENTRY._serialized_start=577
  _CLUSTER_ANNOTATIONSENTRY._serialized_end=627
  _CLUSTER_STATE._serialized_start=629
  _CLUSTER_STATE._serialized_end=710
  _GKECLUSTER._serialized_start=729
  _GKECLUSTER._serialized_end=893
  _EKSCLUSTER._serialized_start=896
  _EKSCLUSTER._serialized_end=1274
  _MINIKUBECLUSTER._serialized_start=1276
  _MINIKUBECLUSTER._serialized_end=1309
  _FAKECLUSTER._serialized_start=1311
  _FAKECLUSTER._serialized_end=1384
  _CREATECLUSTERREQUEST._serialized_start=1386
  _CREATECLUSTERREQUEST._serialized_end=1494
  _GETCLUSTERREQUEST._serialized_start=1496
  _GETCLUSTERREQUEST._serialized_end=1534
  _RECONCILECLUSTERREQUEST._serialized_start=1536
  _RECONCILECLUSTERREQUEST._serialized_end=1580
  _LISTCLUSTERSREQUEST._serialized_start=1583
  _LISTCLUSTERSREQUEST._serialized_end=1718
  _LISTCLUSTERSRESPONSE._serialized_start=1720
  _LISTCLUSTERSRESPONSE._serialized_end=1823
  _UPDATECLUSTERREQUEST._serialized_start=1825
  _UPDATECLUSTERREQUEST._serialized_end=1887
  _DELETECLUSTERREQUEST._serialized_start=1889
  _DELETECLUSTERREQUEST._serialized_end=1930
  _GETCLUSTERCONNECTIONINFOREQUEST._serialized_start=1932
  _GETCLUSTERCONNECTIONINFOREQUEST._serialized_end=1984
  _CLUSTERCONNECTIONINFO._serialized_start=1986
  _CLUSTERCONNECTIONINFO._serialized_end=2044
# @@protoc_insertion_point(module_scope)
